@@ -9,11 +9,13 @@ import signal
 import sys
 import os
 import io
+import operator
 import shutil
 import tempfile
 import time
 import re
 import traceback
+from functools import reduce
 from pathlib import Path
 
 # We don't actually need subprocess in runtests.py, but:
@@ -77,10 +79,10 @@ parser.add_argument("--perf-baseline", type=GitRef, metavar='COMMIT', help="Base
 parser.add_argument("--test-package-db", dest="test_package_db", action="append", help="Package db providing optional packages used by the testsuite.")
 perf_group.add_argument("--skip-perf-tests", action="store_true", help="skip performance tests")
 perf_group.add_argument("--only-perf-tests", action="store_true", help="Only do performance tests")
-perf_group.add_argument("--ignore-perf-failures", choices=['increases','decreases','all'],
+parser.add_argument("--ignore-perf-failures", choices=['increases','decreases','all'],
                         help="Do not fail due to out-of-tolerance perf tests")
-parser.add_argument("--only-report-hadrian-deps", action="store_true",
-                        help="Dry run the testsuite and report all extra hadrian depenedencies needed on stderr")
+parser.add_argument("--only-report-hadrian-deps", type=argparse.FileType('w'),
+                        help="Dry run the testsuite and report all extra hadrian depenedencies needed on the given file")
 
 args = parser.parse_args()
 
@@ -272,13 +274,19 @@ def format_path(path):
 
 # On Windows we need to set $PATH to include the paths to all the DLLs
 # in order for the dynamic library tests to work.
-if windows or darwin:
-    pkginfo = getStdout([config.ghc_pkg, 'dump'])
+if windows:
+    try:
+        pkginfo = getStdout([config.ghc_pkg, 'dump'])
+    except FileNotFoundError as err:
+        # This can happen when we are only running tests which don't depend on ghc (ie linters)
+        # In that case we probably haven't built ghc-pkg yet so this query will fail.
+        print (err)
+        print ("Failed to call ghc-pkg for windows path modification... some tests might fail")
+        pkginfo = ""
     topdir = config.libdir
-    if windows:
-        mingw = os.path.abspath(os.path.join(topdir, '../mingw/bin'))
-        mingw = format_path(mingw)
-        ghc_env['PATH'] = os.pathsep.join([ghc_env.get("PATH", ""), mingw])
+    mingw = os.path.abspath(os.path.join(topdir, '../mingw/bin'))
+    mingw = format_path(mingw)
+    ghc_env['PATH'] = os.pathsep.join([ghc_env.get("PATH", ""), mingw])
     for line in pkginfo.split('\n'):
         if line.startswith('library-dirs:'):
             path = line.rstrip()
@@ -290,12 +298,9 @@ if windows or darwin:
             if path.startswith('"'):
                 path = re.sub('^"(.*)"$', '\\1', path)
                 path = re.sub('\\\\(.)', '\\1', path)
-            if windows:
+
                 path = format_path(path)
                 ghc_env['PATH'] = os.pathsep.join([path, ghc_env.get("PATH", "")])
-            else:
-                # darwin
-                ghc_env['DYLD_LIBRARY_PATH'] = os.pathsep.join([path, ghc_env.get("DYLD_LIBRARY_PATH", "")])
 
 testopts_local.x = TestOptions()
 
@@ -310,10 +315,11 @@ print('Compile ways: ' + ', '.join(config.compile_ways))
 
 # Try get allowed performance changes from the git commit.
 try:
-    config.allowed_perf_changes = Perf.get_allowed_perf_changes()
+    config.allowed_perf_changes = Perf.get_allowed_changes(config.baseline_commit)
 except subprocess.CalledProcessError:
     print('Failed to get allowed metric changes from the HEAD git commit message.')
 
+
 print('Allowing performance changes in: ' + ', '.join(config.allowed_perf_changes.keys()))
 
 # -----------------------------------------------------------------------------
@@ -364,6 +370,12 @@ def cleanup_and_exit(exitcode):
         shutil.rmtree(tempdir, ignore_errors=True)
     exit(exitcode)
 
+def geometric_mean(xs):
+    if len(xs) > 0:
+      return reduce(operator.mul, xs)**(1. / len(xs))
+    else:
+      return 1
+
 def tabulate_metrics(metrics: List[PerfMetric]) -> None:
     abbrevLen = get_abbrev_hash_length()
     hasBaseline = any([x.baseline is not None for x in metrics])
@@ -395,13 +407,22 @@ def tabulate_metrics(metrics: List[PerfMetric]) -> None:
           if x.baseline is not None else "",
         "{}".format(x.baseline.perfStat.test_env)
           if x.baseline is not None else "",
-        "{:13.1f}".format(x.baseline.perfStat.value)
+        "{:13,d}".format(int(x.baseline.perfStat.value))
           if x.baseline is not None else "",
-        "{:13.1f}".format(x.stat.value),
+        "{:13,d}".format(int(x.stat.value)),
         strDiff(x),
         "{}".format(x.change.hint())
     )) for x in sorted(metrics, key =
                       lambda m: (m.stat.test, m.stat.way, m.stat.metric))]
+    geoMean = geometric_mean([
+        x.stat.value / x.baseline.perfStat.value
+        for x in metrics
+        if x.baseline is not None
+    ])
+    dataRows += [
+        row(("", "", "", "", "", "", "", "")),
+        row(("geo. mean", "", "", "", "", "", "{:+4.1f}%".format(100*(geoMean-1)), ""))
+    ]
     print_table(headerRows, dataRows, 1)
     print("")
     if hasBaseline:
@@ -574,7 +595,7 @@ else:
     if config.only_report_hadrian_deps:
       print("WARNING - skipping all tests and only reporting required hadrian dependencies:", config.hadrian_deps)
       for d in config.hadrian_deps:
-        print(d,file=sys.stderr)
+        print(d,file=config.only_report_hadrian_deps)
 
 if len(t.unexpected_failures) > 0 or \
    len(t.unexpected_stat_failures) > 0 or \
@@ -587,7 +608,7 @@ else:
 cleanup_and_exit(exitcode)
 
 # Note [Running tests in /tmp]
-#
+# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 # Use LOCAL=0 to run tests in /tmp, to catch tests that use files from
 # the source directory without copying them to the test directory first.
 #
